@@ -1,19 +1,23 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2022-2023, by Samuel Williams.
+# Copyright, 2022-2024, by Samuel Williams.
 
-require 'rack'
-
-require_relative 'adapter/rack2'
-require_relative 'adapter/rack3'
+require "rack"
 
 module Protocol
 	module Rack
 		module Adapter
-			if ::Rack.release >= "3"
+			VERSION = ENV.fetch("PROTOCOL_RACK_ADAPTER_VERSION", ::Rack.release)
+			
+			if VERSION >= "3.1"
+				require_relative "adapter/rack31"
+				IMPLEMENTATION = Rack31
+			elsif VERSION >= "3"
+				require_relative "adapter/rack3"
 				IMPLEMENTATION = Rack3
 			else
+				require_relative "adapter/rack2"
 				IMPLEMENTATION = Rack2
 			end
 			
@@ -24,6 +28,10 @@ module Protocol
 			def self.make_response(env, response)
 				IMPLEMENTATION.make_response(env, response)
 			end
+			
+			def self.parse_file(...)
+				IMPLEMENTATION.parse_file(...)
+			end
 		end
 	end
 end
